@@ -2,24 +2,25 @@
 
 // this function returns the set of characters that are defined by a
 // predefined setname.
-// To determine the set of characters s_hash is used. It is an unordered_map
+// To determine the set of characters s_hash is used. It is an FBB::LinearMap
 // initialized to an empty set in `data.cc', and it is filled with its
 // characters the first time it is used. At the same time the negated set is
 // filled. 
 
-set<char> const &CharRange::predefined(std::string const &setName)
+string const &CharRange::predefined(std::string const &setName)
 {
-    size_t const beyond = numeric_limits<unsigned char>::max() + 1;
+    size_t const beyond = FlexTypes::NCHARS;
 
-    auto &chSet = s_hash[setName];
+    auto &str = s_hash[setName];
 
-    if (chSet.empty())
+    if (str.empty())
     {
         if (setName == ".")
         {
-            copy(AllChars(0), AllChars(beyond), inserter(chSet, chSet.end()));
-            chSet.erase('\n');
-            return chSet;
+            str.append(Iterator<char>::min(), Iterator<char>('\n'));
+            str.append(Iterator<char>('\n' + 1), 
+                       Iterator<char>::last(*Iterator<char>::max()));
+            return str;
         }
 
         string setToFill = setName;
@@ -35,9 +36,10 @@ set<char> const &CharRange::predefined(std::string const &setName)
 
         for (size_t idx = 0; idx != beyond; ++idx)
             if (fillFun(idx))
-                fillSet.insert(idx);
+                fillSet += idx;
 
         s_hash[complementedSet] = negate(fillSet);
     }
-    return chSet;
+    return str;
 }
+
