@@ -7,13 +7,14 @@ void DFARow::tabulateFinals(Table &table) const
 
     ostringstream out;
 
-    if (first != UINT_MAX)
+    if (first != max<size_t>())
     {
         out << d_finalRule.first;
-        if (second != UINT_MAX)
+        if (second != max<size_t>())
             out << ',';
     }
-    if (second != UINT_MAX)
+
+    if (second != max<size_t>())
         out << second;
 
     table << out.str();
