@@ -9,14 +9,14 @@ void Generator::debug(ostream &out) const
 
     key(out);
 
-    out << indent << "if (s_debug__)\n" <<
+    out << indent << "if (s_debug_)\n" <<
            indent << "    " << flush;
 
     if (*d_line.rbegin() != '+')
-        out <<  "s_out__ << " << d_line << " << \"\\n\" << dflush__;\n";
+        out <<  "s_out_ << " << d_line << " << \"\\n\" << dflush_;\n";
     else
     {
         d_line.resize(d_line.length() - 1);
-        out <<  "s_out__ << " << d_line << ";\n";
+        out <<  "s_out_ << " << d_line << ";\n";
     }
 }
