@@ -6,8 +6,9 @@ void Generator::inputInterface(std::ostream &out) const
 
     key(out);
 
-    if (not interface.empty())
-        out << "#include \"" << interface << "\"\n";
+    if (not interface.empty())              // user-provided input interface
+        out << "protected:\n"               // have protected access rights
+               "#include \"" << interface << "\"\n";
     else
         out <<
 R"(
@@ -46,7 +47,16 @@ R"(
         private:
             size_t next();                  // obtain the next character
     };
+
+protected:
 )";     
 // >>>> R"( section ends <<<<
 
 }
+
+
+
+
+
+
+
