@@ -7,14 +7,18 @@ char const interactive[] = R"_(    d_in(&in),
     d_line(new std::istringstream()),
     d_dfaBase_(s_dfa_)
 {
-    p_pushStream("(istream)", new std::istream(d_line->rdbuf()));
+    if (keepCwd)
+        d_cwd = std::filesystem::current_path().string();
+    p_pushStream(s_istream, new std::istream(d_line->rdbuf()));
 }
 )_";
 
 char const nonInteractive[] = R"_(    d_in(0),
     d_dfaBase_(s_dfa_)
 {
-    p_pushStream("(istream)", new std::istream(in.rdbuf()));
+    if (keepCwd)
+        d_cwd = std::filesystem::current_path().string();
+    p_pushStream(s_istream, new std::istream(in.rdbuf()));
 }
 )_";
 
