@@ -1,11 +1,11 @@
 #include "options.ih"
 
-void Options::setClassName()
+void Options::setClassName(TextType textType)
 {
     if (d_className.size())
         emsg << "%class-name multiply specified" << endl;
     else
-        d_className = undelimit(*d_matched);
+        d_className = textOf(textType);
 
     s_warnOptions.insert("class-name");
 }
