@@ -11,7 +11,7 @@ Parser::Parser(Rules &rules, States &states)
     d_states(states)
 {
     d_options.setParserInfo(d_matched, d_rawStringContents);
-    s_ignoreToken = token__();      // set by ParserBase to _UNDETERMINED
+    s_ignoreToken = token_();      // set by ParserBase to _UNDETERMINED
 //    setDebug(d_options.debug());    // write debug code to the generated
                                     // lex.cc file 
     setDebug(d_options.ownParserDebug());
