@@ -2,8 +2,6 @@
 #include <fstream>
 #include <sstream>
 #include <stdexcept>
-
-//FBB
 #include <filesystem>
 
 $insert class_ih
@@ -32,7 +30,7 @@ size_t \@Base::s_istreamNr = 0;
 
 $insert inputImplementation
 
-\@Base::\@Base(std::istream &in, std::ostream &out)
+\@Base::\@Base(std::istream &in, std::ostream &out, bool keepCwd)
 :
     d_out(new std::ostream(out.rdbuf())),
 $insert interactiveInit
@@ -45,14 +43,18 @@ void \@Base::switchStream_(std::istream &in, size_t lineNr)
 
 $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
 
-\@Base::\@Base(std::string const &infilename, std::string const &outfilename)
+\@Base::\@Base(std::string const &infilename, std::string const &outfilename, bool keepCwd)
 :
     d_out(outfilename == "-"    ? new std::ostream(std::cout.rdbuf()) :
           outfilename == ""     ? new std::ostream(std::cerr.rdbuf()) :
                                   new std::ofstream(outfilename)),
     d_dfaBase_(s_dfa_)
 {
+    if (keepCwd)
+        d_cwd = std::filesystem::current_path().string();
+
     p_pushStream(infilename, { new std::ifstream(infilename) });
+    toCwd();
 }
 
 void \@Base::switchStreams(std::istream &in, std::ostream &out)
@@ -65,7 +67,11 @@ void \@Base::switchIstream(std::string const &infilename)
 {
     d_input->close();
     d_filename = infilename;
-    d_streamStack.back().input = new std::ifstream(infilename);
+
+    d_streamStack.back() = 
+        StreamStruct{ chgWorkingDir(d_filename), 
+                      { new std::ifstream(infilename) } };
+
     d_atBOL = true;
 }
 
@@ -95,17 +101,30 @@ void \@Base::pushStream(std::string const &name)
 $ignoreInteractive END      end ignored section by generator/filter.cc
 
 
-// static
-std::string \@Base::setCwd(std::string const &name)     // any name
+void \@Base::toCwd() const
 {
     using namespace std;
     using namespace filesystem;
 
+    if (d_cwd.empty())
+        return;
+
     error_code ec;
-    if (not exists(name, ec))                           // not a filename
+    current_path(d_cwd, ec);
+};
+
+// static
+std::string \@Base::chgWorkingDir(std::string const &name)     // any name
+{
+    using namespace std;
+    using namespace filesystem;
+
+    if (name == s_istream)                              // used with istreams
         return name;
                                                         // a filename: get its
-    auto path = canonical(name);                        // full pathname
+    auto path = absolute(name);                         // full pathname
+
+    error_code ec;
     current_path(path.parent_path(), ec);
 
     return path.string();                               // return the pathname
@@ -120,7 +139,9 @@ void \@Base::p_pushStream(std::string const &name, std::istream *streamPtr)
     }
 
     d_filename = name;
-    d_streamStack.push_back(StreamStruct{setCwd(d_filename), { streamPtr } });
+    d_streamStack.push_back(
+                    StreamStruct{chgWorkingDir(d_filename), { streamPtr } }
+                  );
 
     d_input = &d_streamStack.back().input;
 
@@ -163,8 +184,8 @@ bool \@Base::popStream()
 
     d_streamStack.pop_back();
 
-    d_filename = 
-        path{ setCwd(d_streamStack.back().pushedName) }.filename().string();
+    d_filename = path{ chgWorkingDir(d_streamStack.back().pushedName) 
+                     }.filename().string();
 
     d_input = &d_streamStack.back().input;
 
@@ -377,7 +398,7 @@ int \@::lex_()
                 if (return_())
                 {
                     print();
-                    postCode(PostEnum_::RETURN);
+                    toCwd();
                     return d_token_;
                 }
                 break;
@@ -396,6 +417,7 @@ $insert 16 debug  "EOF_REACHED"
                 if (!popStream())
                 {
                      postCode(PostEnum_::END);
+                     toCwd();
                      return 0;
                 }
                 postCode(PostEnum_::POP);
